from bluer_ugv.README.swallow.consts import swallow_assets2
from bluer_ugv.README.arzhang.consts import arzhang_assets, arzhang_assets2
from bluer_ugv.README.rangin.consts import rangin_assets2, rangin_mechanical_design

dict_of_ugvs = {
    "swallow": {
        "order": 1,
        "cols": 1,
        "items": [
            f"{swallow_assets2}/20250701_2206342_1.gif",
            f"{swallow_assets2}/20250913_203635~2_1.gif",
            f"{swallow_assets2}/20251216_205015.jpg",
        ],
    },
    "arzhang": {
        "order": 2,
        "items": [
            f"{arzhang_assets2}/20251209_111322.jpg",
        ],
    },
    "arzhang2": {
        "order": 3,
        "items": [
            f"{arzhang_assets2}/20251210_154513.jpg",
        ],
    },
    "arzhang3": {
        "order": 4,
        "items": sorted(
            [
                f"{arzhang_assets}/20251107_175506.jpg",
                f"{arzhang_assets2}/20251128_175614.jpg",
                f"{arzhang_assets2}/20251202_100317.jpg",
                f"{arzhang_assets2}/20251202_101031.jpg",
                f"{arzhang_assets2}/20251128_113314.jpg",
                f"{arzhang_assets2}/20251128_151952.jpg",
                f"{arzhang_assets2}/20251128_155616.jpg",
                f"{arzhang_assets2}/20251130_140103.jpg",
                f"{arzhang_assets2}/20251203_112602.jpg",
                f"{arzhang_assets2}/20251210_154654.jpg",
            ]
        ),
    },
    "rangin": {
        "order": 5,
        "items": [
            f"{rangin_mechanical_design}/robot.png",
            f"{rangin_assets2}/20251221_125120.jpg",
            f"{rangin_assets2}/20251222_104404.jpg",
            f"{rangin_assets2}/20251222_110634.jpg",
            f"{rangin_assets2}/20251222_160737.jpg",
            f"{rangin_assets2}/20251222_165829.jpg",
            f"{rangin_assets2}/20251222_173509.jpg",
        ],
    },
}



import threading
import time


from bluer_sbc.env import BLUER_SBC_AUDIO_ENABLED

from bluer_ugv.logger import logger


class ClassicalAudio:
    def __init__(
        self,
    ):
        self.enabled = BLUER_SBC_AUDIO_ENABLED == 1
        logger.info(
            "{}: {}".format(
                self.__class__.__name__,
                ("enabled" if self.enabled else "disabled"),
            )
        )

        self.running = False

        if not self.enabled:
            return

        self.running = True
        self.thread = threading.Thread(target=self.loop, daemon=True)
        self.thread.start()

    def stop(self):
        if not self.enabled:
            return

        self.running = False
        self.thread.join()

        logger.info(f"{self.__class__.__name__}.stopped.")

    def loop(self):
        logger.info(f"{self.__class__.__name__}.loop started.")

        while self.running:
            time.sleep(5)
            logger.info("audio loop 🪄")



from typing import List

from bluer_options.terminal import show_usage
from bluer_sbc import env


def help_cp(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@swallow",
            "env",
            "cp",
            "[<env-name>]",
        ],
        "cp swallow-raspbian-<env-name>.env.",
        mono=mono,
    )


def help_list(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@swallow",
            "env",
            "list",
        ],
        "list swallow envs.",
        mono=mono,
    )


def help_set(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@swallow",
            "env",
            "set",
            "bps | camera | full_keyboard | screen | steering",
            "0 | 1",
        ],
        "set env.",
        {
            f"bps: BLUER_SBC_SWALLOW_HAS_BPS (currently: {env.BLUER_SBC_SWALLOW_HAS_BPS})": "",
            f"camera: BLUER_SBC_SWALLOW_HAS_CAMERA (currently: {env.BLUER_SBC_SWALLOW_HAS_CAMERA})": "",
            f"full_keyboard: BLUER_SBC_SWALLOW_HAS_FULL_KEYBOARD (currently: {env.BLUER_SBC_SWALLOW_HAS_FULL_KEYBOARD})": "",
            f" screen: BLUER_SBC_ENABLE_SCREEN (currently: {env.BLUER_SBC_ENABLE_SCREEN})"
            f"steering: BLUER_SBC_SWALLOW_HAS_STEERING (currently: {env.BLUER_SBC_SWALLOW_HAS_STEERING})": "",
        },
        mono=mono,
    )


help_functions = {
    "cp": help_cp,
    "list": help_list,
    "set": help_set,
}
